intelmq.bots.experts.http package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.experts.http package

## Submodules

## intelmq.bots.experts.http.expert_status module

HTTP Status Expert Bot

SPDX-FileCopyrightText: 2021 Birger Schacht <schacht@cert.at> SPDX-License-Identifier: AGPL-3.0-or-later

`intelmq.bots.experts.http.expert_status.` `BOT`

  alias of `intelmq.bots.experts.http.expert_status.HttpStatusExpertBot`

class `intelmq.bots.experts.http.expert_status.` `HttpStatusExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Fetch the HTTP Status for a given URL

  field: str

    The name of the field containing the URL to be checked (defaults to ‘source.url’).

  success_status_codes: List

    A list of success status codes. If this parameter is omitted or the list is empty, successful status codes are the ones between 200 and 400.

  overwrite:

    Specifies if an existing ‘status’ value should be overwritten.

  `field`: str = 'source.url'
  `overwrite`: bool = True
  `process`()
  `success_status_codes`: List[int] = []

## Module contents